@@ -23,7 +23,7 @@ class MatchResult:
     def __eq__(self, other: "MatchResult"):
         try:
             np.testing.assert_equal(self.indices, other.indices)
-            np.testing.assert_almost_equal(self.distances, other.distances, decimal=5)
+            np.testing.assert_almost_equal(self.distances, other.distances, decimal=4)
         except AssertionError:
             return False
         return True
@@ -52,12 +52,6 @@ class Matcher(ABC):
 class FastL2CCBFMatcher(Matcher):
     """Brute force matcher equivalent to cv2.BFMatcher(NORM_L2, cross_check=True)"""
 
-    @classmethod
-    def l2_distance_matrix(cls, X: np.ndarray, Y: np.ndarray) -> np.ndarray:
-        D = np.zeros([X.shape[0], Y.shape[0]], np.float32)
-        mops.l2_distance_matrix(X, Y, D)
-        return D
-
     def match(self, X: np.ndarray, Y: np.ndarray) -> MatchResult:
         X, Y = self.cast_inputs(X, Y)
         indices, distances = mops.l2_cross_check_matcher(X, Y)
@@ -77,3 +71,9 @@ class FastL2RTBFMatcher(Matcher):
         X, Y = self.cast_inputs(X, Y)
         indices, distances = mops.l2_ratio_test_matcher(X, Y, ratio=self.ratio)
         return MatchResult(indices, distances)
+
+
+def l2_distance_matrix(X: np.ndarray, Y: np.ndarray) -> np.ndarray:
+    D = np.zeros([X.shape[0], Y.shape[0]], np.float32)
+    mops.l2_distance_matrix(X, Y, D)
+    return D
